#!/usr/bin/env python

black_bishop = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess bdt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="21.47589" inkscape:cy="21.674445" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1" style="display: inline;">
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 9,36 C 12.385255,35.027671 19.114744,36.430821 22.5,34 C 25.885256,36.430821 32.614745,35.027671 36,36 C 36,36 37.645898,36.541507 39,38 C 38.322949,38.972328 37.354102,38.986164 36,38.5 C 32.614745,37.527672 25.885256,38.958493 22.5,37.5 C 19.114744,38.958493 12.385255,37.527672 9,38.5 C 7.6458978,38.986164 6.6770511,38.972328 6,38 C 7.3541023,36.055343 9,36 9,36 z " id="path4582" sodipodi:nodetypes="ccccccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 15,32 C 17.5,34.5 27.5,34.5 30,32 C 30.5,30.5 30,30 30,30 C 30,27.5 27.5,26 27.5,26 C 33,24.5 33.5,14.5 22.5,10.5 C 11.5,14.5 12,24.5 17.5,26 C 17.5,26 15,27.5 15,30 C 15,30 14.5,30.5 15,32 z " id="path4584" sodipodi:nodetypes="cccccccc"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path4586" sodipodi:cx="22.5" sodipodi:cy="10" sodipodi:rx="2.5" sodipodi:ry="2.5" d="M 25 10 A 2.5 2.5 0 1 1  20,10 A 2.5 2.5 0 1 1  25 10 z" transform="translate(0, -2)"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 17.5,26 L 27.5,26" id="path4588" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 15,30 L 30,30" id="path4590" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 22.5,15.5 L 22.5,20.5" id="path4592"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 20,18 L 25,18" id="path4594"/>
  </g>
</svg>
"""

black_king = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess kdt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="11.313708" inkscape:cx="50.19508" inkscape:cy="20.61116" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="1272" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 22.5,11.625 L 22.5,6" id="path6570"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 22.5,25 C 22.5,25 27,17.5 25.5,14.5 C 25.5,14.5 24.5,12 22.5,12 C 20.5,12 19.5,14.5 19.5,14.5 C 18,17.5 22.5,25 22.5,25" id="path5683" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,37 C 17,40.5 27,40.5 32.5,37 L 32.5,30 C 32.5,30 41.5,25.5 38.5,19.5 C 34.5,13 25,16 22.5,23.5 L 22.5,27 L 22.5,23.5 C 19,16 9.5,13 6.5,19.5 C 3.5,25.5 11.5,29.5 11.5,29.5 L 11.5,37 z " id="path5681" sodipodi:nodetypes="cccccccccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 20,8 L 25,8" id="path6572"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,29.5 C 17,27 27,27 32.5,30" id="path6574" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,37 C 17,34.5 27,34.5 32.5,37" id="path6576" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,33.5 C 17,31.5 27,31.5 32.5,33.5" id="path6578" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 1; fill-rule: evenodd; stroke: white; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 32,29.5 C 32,29.5 40.5,25.5 38.025969,19.846552 C 34.147406,13.996552 25,18 22.5,24.5 L 22.511718,26.596552 L 22.5,24.5 C 20,18 9.9063892,13.996552 6.9974672,19.846552 C 4.5,25.5 11.845671,28.846552 11.845671,28.846552" id="path5638" sodipodi:nodetypes="ccccccc"/>
  </g>
</svg>
"""

black_knight = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess ndt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="8" inkscape:cx="37.995338" inkscape:cy="23.908871" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.05px" gridspacingy="0.05px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 22,10 C 32.5,11 38.5,18 38,39 L 15,39 C 15,30 25,32.5 23,18" id="path3491" sodipodi:nodetypes="cccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 24,18 C 24.384461,20.911278 18.447064,25.368624 16,27 C 13,29 13.180802,31.342892 11,31 C 9.95828,30.055984 12.413429,27.962451 11,28 C 10,28 11.187332,29.231727 10,30 C 9,30 5.9968392,30.999999 6,26 C 6,24 12,14 12,14 C 12,14 13.885866,12.097871 14,10.5 C 13.273953,9.505631 13.5,8.5 13.5,7.5 C 14.5,6.5 16.5,10 16.5,10 L 18.5,10 C 18.5,10 19.281781,8.0080745 21,7 C 22,7 22,10 22,10" id="path3495" sodipodi:nodetypes="csccccccccccc"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: white; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path3499" sodipodi:cx="8.5" sodipodi:cy="23.5" sodipodi:rx="0.5" sodipodi:ry="0.5" d="M 9 23.5 A 0.5 0.5 0 1 1  8,23.5 A 0.5 0.5 0 1 1  9 23.5 z" transform="translate(0.5, 2)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: white; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path3501" sodipodi:cx="14.5" sodipodi:cy="15.5" sodipodi:rx="0.5" sodipodi:ry="1.5" d="M 15 15.5 A 0.5 1.5 0 1 1  14,15.5 A 0.5 1.5 0 1 1  15 15.5 z" transform="matrix(0.866025, 0.5, -0.5, 0.866025, 9.69263, -5.17339)"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: none; stroke-width: 1; stroke-linecap: square; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 24.55,10.4 L 24.25,11.5 L 24.8,11.6 C 27.901459,12.077147 31.123526,13.834204 33.375,18.09375 C 35.626474,22.353296 36.297157,29.05687 35.8,39 L 35.75,39.5 L 37.5,39.5 L 37.5,39 C 38.002843,28.94313 36.623526,22.146704 34.25,17.65625 C 31.876474,13.165796 28.461041,11.022853 25.0625,10.5 L 24.55,10.4 z " id="path8049" sodipodi:nodetypes="cccsccccscc"/>
  </g>
</svg>
"""

black_pawn = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess pdt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="11.2" inkscape:cx="22.89394" inkscape:cy="17.72157" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="opacity: 1; fill: black; fill-opacity: 1; fill-rule: nonzero; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-dashoffset: 10; stroke-opacity: 1;" d="M 22 9 C 19.792 9 18 10.792 18 13 C 18 13.885103 18.29397 14.712226 18.78125 15.375 C 16.829274 16.496917 15.5 18.588492 15.5 21 C 15.5 23.033947 16.442042 24.839082 17.90625 26.03125 C 14.907101 27.08912 10.5 31.578049 10.5 39.5 L 33.5 39.5 C 33.5 31.578049 29.092899 27.08912 26.09375 26.03125 C 27.557958 24.839082 28.5 23.033948 28.5 21 C 28.5 18.588492 27.170726 16.496917 25.21875 15.375 C 25.70603 14.712226 26 13.885103 26 13 C 26 10.792 24.208 9 22 9 z " id="path3194"/>
  </g>
</svg>
"""

black_queen = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess qdt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="34.028184" inkscape:cy="22.902797" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="1272" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5571" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(-1, -1)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5573" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(15.5, -5.5)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5575" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(32, -1)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5577" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(7, -4.5)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5579" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(24, -4)"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1;" d="M 9,26 C 17.5,24.5 30,24.5 36,26 L 38,14 L 31,25 L 31,11 L 25.5,24.5 L 22.5,9.5 L 19.5,24.5 L 14,10.5 L 14,25 L 7,14 L 9,26 z " id="path5581" sodipodi:nodetypes="cccccccccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1;" d="M 9,26 C 9,28 10.5,28 11.5,30 C 12.5,31.5 12.5,31 12,33.5 C 10.5,34.5 10.5,36 10.5,36 C 9,37.5 11,38.5 11,38.5 C 17.5,39.5 27.5,39.5 34,38.5 C 34,38.5 35.5,37.5 34,36 C 34,36 34.5,34.5 33,33.5 C 32.5,31 32.5,31.5 33.5,30 C 34.5,28 36,28 36,26 C 27.5,24.5 17.5,24.5 9,26 z " id="path5583" sodipodi:nodetypes="ccccccccccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 11.5,30 C 15,29 30,29 33.5,30" id="path5585" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 12,33.5 C 18,32.5 27,32.5 33,33.5" id="path5587" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 10.5,36 C 15.5,35 29,35 34,36" id="path5589" sodipodi:nodetypes="cc"/>
  </g>
</svg>
"""

black_rook = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess rdt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="19.736579" inkscape:cy="22.06684" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="852" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1" style="display: inline;">
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 9,39 L 36,39 L 36,36 L 9,36 L 9,39 z " id="path3119" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 12.5,32 L 14,29.5 L 31,29.5 L 32.5,32 L 12.5,32 z " id="path3123" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 12,36 L 12,32 L 33,32 L 33,36 L 12,36 z " id="path3121" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 14,29.5 L 14,16.5 L 31,16.5 L 31,29.5 L 14,29.5 z " id="path3125" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 14,16.5 L 11,14 L 34,14 L 31,16.5 L 14,16.5 z " id="path3127" sodipodi:nodetypes="ccccc"/>
    <path style="fill: black; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11,14 L 11,9 L 15,9 L 15,11 L 20,11 L 20,9 L 25,9 L 25,11 L 30,11 L 30,9 L 34,9 L 34,14 L 11,14 z " id="path3129" sodipodi:nodetypes="ccccccccccccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 12,35.5 L 33,35.5 L 33,35.5" id="path4967"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 13,31.5 L 32,31.5" id="path4969"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 14,29.5 L 31,29.5" id="path4971"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 14,16.5 L 31,16.5" id="path5050"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: white; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 11,14 L 34,14" id="path5052"/>
  </g>
</svg>
"""

white_king = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess klt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="11.313708" inkscape:cx="42.721441" inkscape:cy="13.400149" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="1272" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 22.5,11.625 L 22.5,6" id="path6570"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 22.5,25 C 22.5,25 27,17.5 25.5,14.5 C 25.5,14.5 24.5,12 22.5,12 C 20.5,12 19.5,14.5 19.5,14.5 C 18,17.5 22.5,25 22.5,25" id="path5683" sodipodi:nodetypes="ccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,37 C 17,40.5 27,40.5 32.5,37 L 32.5,30 C 32.5,30 41.5,25.5 38.5,19.5 C 34.5,13 25,16 22.5,23.5 L 22.5,27 L 22.5,23.5 C 19,16 9.5,13 6.5,19.5 C 3.5,25.5 11.5,29.5 11.5,29.5 L 11.5,37 z " id="path5681" sodipodi:nodetypes="cccccccccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 20,8 L 25,8" id="path6572"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,29.5 C 17,27 27,27 32.5,30" id="path6574" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,37 C 17,34.5 27,34.5 32.5,37" id="path6576" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11.5,33.5 C 17,31.5 27,31.5 32.5,33.5" id="path6578" sodipodi:nodetypes="cc"/>
  </g>
</svg>"""

white_queen = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess qlt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="34.028184" inkscape:cy="22.902797" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="1272" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5571" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(-1, -1)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5573" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(15.5, -5.5)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5575" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(32, -1)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5577" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(7, -4.5)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path5579" sodipodi:cx="7" sodipodi:cy="13" sodipodi:rx="2" sodipodi:ry="2" d="M 9 13 A 2 2 0 1 1  5,13 A 2 2 0 1 1  9 13 z" transform="translate(24, -4)"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 9,26 C 17.5,24.5 30,24.5 36,26 L 38,14 L 31,25 L 31,11 L 25.5,24.5 L 22.5,9.5 L 19.5,24.5 L 14,10.5 L 14,25 L 7,14 L 9,26 z " id="path5581" sodipodi:nodetypes="cccccccccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 9,26 C 9,28 10.5,28 11.5,30 C 12.5,31.5 12.5,31 12,33.5 C 10.5,34.5 10.5,36 10.5,36 C 9,37.5 11,38.5 11,38.5 C 17.5,39.5 27.5,39.5 34,38.5 C 34,38.5 35.5,37.5 34,36 C 34,36 34.5,34.5 33,33.5 C 32.5,31 32.5,31.5 33.5,30 C 34.5,28 36,28 36,26 C 27.5,24.5 17.5,24.5 9,26 z " id="path5583" sodipodi:nodetypes="ccccccccccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 11.5,30 C 15,29 30,29 33.5,30" id="path5585" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 12,33.5 C 18,32.5 27,32.5 33,33.5" id="path5587" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1;" d="M 10.5,36 C 15.5,35 29,35 34,36" id="path5589" sodipodi:nodetypes="cc"/>
  </g>
</svg>
"""

white_rook = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess rlt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="11.313709" inkscape:cx="25.614263" inkscape:cy="20.600169" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="852" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1" style="display: inline;">
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 9,39 L 36,39 L 36,36 L 9,36 L 9,39 z " id="path3119" sodipodi:nodetypes="ccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 12,36 L 12,32 L 33,32 L 33,36 L 12,36 z " id="path3121" sodipodi:nodetypes="ccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 11,14 L 11,9 L 15,9 L 15,11 L 20,11 L 20,9 L 25,9 L 25,11 L 30,11 L 30,9 L 34,9 L 34,14" id="path3129" sodipodi:nodetypes="cccccccccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 34,14 L 31,17 L 14,17 L 11,14" id="path3127" sodipodi:nodetypes="cccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 31,17 L 31,29.500018 L 14,29.500018 L 14,17" id="path3125" sodipodi:nodetypes="cccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 31,29.5 L 32.5,32 L 12.5,32 L 14,29.5" id="path3123" sodipodi:nodetypes="cccc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1px; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1;" d="M 11,14 L 34,14" id="path5175"/>
  </g>
</svg>
"""

white_bishop = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess blt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="21.47589" inkscape:cy="21.674445" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1" style="display: inline;">
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 9,36 C 12.385255,35.027671 19.114744,36.430821 22.5,34 C 25.885256,36.430821 32.614745,35.027671 36,36 C 36,36 37.645898,36.541507 39,38 C 38.322949,38.972328 37.354102,38.986164 36,38.5 C 32.614745,37.527672 25.885256,38.958493 22.5,37.5 C 19.114744,38.958493 12.385255,37.527672 9,38.5 C 7.6458978,38.986164 6.6770511,38.972328 6,38 C 7.3541023,36.055343 9,36 9,36 z " id="path4582" sodipodi:nodetypes="ccccccccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 15,32 C 17.5,34.5 27.5,34.5 30,32 C 30.5,30.5 30,30 30,30 C 30,27.5 27.5,26 27.5,26 C 33,24.5 33.5,14.5 22.5,10.5 C 11.5,14.5 12,24.5 17.5,26 C 17.5,26 15,27.5 15,30 C 15,30 14.5,30.5 15,32 z " id="path4584" sodipodi:nodetypes="cccccccc"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: white; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path4586" sodipodi:cx="22.5" sodipodi:cy="10" sodipodi:rx="2.5" sodipodi:ry="2.5" d="M 25 10 A 2.5 2.5 0 1 1  20,10 A 2.5 2.5 0 1 1  25 10 z" transform="translate(0, -2)"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 17.5,26 L 27.5,26" id="path4588" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 15,30 L 30,30" id="path4590" sodipodi:nodetypes="cc"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 22.5,15.5 L 22.5,20.5" id="path4592"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" d="M 20,18 L 25,18" id="path4594"/>
  </g>
  <g inkscape:groupmode="layer" id="layer2" inkscape:label="Layer 1#1" style="display: inline;"/>
</svg>
"""

white_knight = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess nlt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="16" inkscape:cx="24.795834" inkscape:cy="23.520246" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 22,10 C 32.5,11 38.5,18 38,39 L 15,39 C 15,30 25,32.5 23,18" id="path3491" sodipodi:nodetypes="cccc"/>
    <path style="fill: white; fill-opacity: 1; fill-rule: evenodd; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 24,18 C 24.384461,20.911278 18.447064,25.368624 16,27 C 13,29 13.180802,31.342892 11,31 C 9.95828,30.055984 12.413429,27.962451 11,28 C 10,28 11.187332,29.231727 10,30 C 9,30 5.9968392,30.999999 6,26 C 6,24 12,14 12,14 C 12,14 13.885866,12.097871 14,10.5 C 13.273953,9.505631 13.5,8.5 13.5,7.5 C 14.5,6.5 16.5,10 16.5,10 L 18.5,10 C 18.5,10 19.281781,8.0080745 21,7 C 22,7 22,10 22,10" id="path3495" sodipodi:nodetypes="csccccccccccc"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path3499" sodipodi:cx="8.5" sodipodi:cy="23.5" sodipodi:rx="0.5" sodipodi:ry="0.5" d="M 9 23.5 A 0.5 0.5 0 1 1  8,23.5 A 0.5 0.5 0 1 1  9 23.5 z" transform="translate(0.5, 2)"/>
    <path sodipodi:type="arc" style="opacity: 1; fill: black; fill-opacity: 1; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: round; stroke-miterlimit: 4; stroke-dasharray: none; stroke-opacity: 1;" id="path3501" sodipodi:cx="14.5" sodipodi:cy="15.5" sodipodi:rx="0.5" sodipodi:ry="1.5" d="M 15 15.5 A 0.5 1.5 0 1 1  14,15.5 A 0.5 1.5 0 1 1  15 15.5 z" transform="matrix(0.866025, 0.5, -0.5, 0.866025, 9.69263, -5.17339)"/>
    <path style="fill: none; fill-opacity: 0.75; fill-rule: evenodd; stroke: black; stroke-width: 1; stroke-linecap: round; stroke-linejoin: miter; stroke-opacity: 1; stroke-miterlimit: 4; stroke-dasharray: none;" d="M 37,39 C 38,19 31.5,11.5 25,10.5" id="path8049" sodipodi:nodetypes="cc"/>
  </g>
</svg>
"""

white_pawn = """\
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->
<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://web.resource.org/cc/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" width="45" height="45" id="svg3128" sodipodi:version="0.32" inkscape:version="0.44.1" version="1.0" sodipodi:docbase="/home/cburnett/wikipedia/images/chess" sodipodi:docname="Chess plt45.svg">
  <defs id="defs3130"/>
  <sodipodi:namedview id="base" pagecolor="#ffffff" bordercolor="#666666" borderopacity="1.0" gridtolerance="10000" guidetolerance="10" objecttolerance="10" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:zoom="11.2" inkscape:cx="22.89394" inkscape:cy="17.72157" inkscape:document-units="px" inkscape:current-layer="layer1" height="45px" width="45px" inkscape:grid-points="true" showgrid="true" inkscape:window-width="977" inkscape:window-height="965" inkscape:window-x="0" inkscape:window-y="31" gridspacingx="0.5px" gridspacingy="0.5px"/>
  <metadata id="metadata3133">
    <rdf:RDF>
      <cc:Work rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g inkscape:label="Layer 1" inkscape:groupmode="layer" id="layer1">
    <path style="opacity: 1; fill: white; fill-opacity: 1; fill-rule: nonzero; stroke: black; stroke-width: 1.5; stroke-linecap: round; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-dasharray: none; stroke-dashoffset: 10; stroke-opacity: 1;" d="M 22 9 C 19.792 9 18 10.792 18 13 C 18 13.885103 18.29397 14.712226 18.78125 15.375 C 16.829274 16.496917 15.5 18.588492 15.5 21 C 15.5 23.033947 16.442042 24.839082 17.90625 26.03125 C 14.907101 27.08912 10.5 31.578049 10.5 39.5 L 33.5 39.5 C 33.5 31.578049 29.092899 27.08912 26.09375 26.03125 C 27.557958 24.839082 28.5 23.033948 28.5 21 C 28.5 18.588492 27.170726 16.496917 25.21875 15.375 C 25.70603 14.712226 26 13.885103 26 13 C 26 10.792 24.208 9 22 9 z " id="path3194"/>
  </g>
</svg>
"""